@@ -27,6 +27,7 @@ from ubiquity import misc
 import os
 import subprocess
 import shutil
+import time
 
 NAME = 'myth-installtype'
 HIDDEN = 'webcam'
@@ -106,7 +107,7 @@ class Install(InstallPlugin):
         if 'Slave' in self.type or self.type == 'Frontend':
             packages.add('ntp')              #causes mythtv-backend-master to go
             packages.add('mythtv-database')
-            packages.add('mysql-server-core-5.1')
+            packages.add('mysql-server-core-5.5')
         if 'Frontend' not in self.type:
             packages.add('mythtv-frontend')
         ## services that are installed by default
@@ -147,12 +148,14 @@ class Install(InstallPlugin):
             #Setup sql server
             #TODO, workaround for bug http://www.launchpad.net/bugs/729338
             subprocess.call(['sysctl', '-w', 'kernel.yama.protected_nonaccess_hardlinks=0'])
-            install_misc.reconfigure(self.target, 'mysql-server-5.1')
+            install_misc.reconfigure(self.target, 'mysql-server-5.5')
 
             #upstart managed chroot job, 
             #we need stuff working INSIDE the chroot.
             subprocess.call(['chroot', self.target, 'stop', 'mysql'])
             proc=subprocess.Popen(['chroot',self.target,'mysqld'])
+            while not os.path.exists(os.path.join(self.target, 'run', 'mysqld', 'mysqld.sock')):
+                time.sleep(1)
 
             #build database
             install_misc.reconfigure(self.target, 'mythtv-database')
